@@ -10,6 +10,7 @@ use English qw(-no_match_vars);
 use XML::TreePP;
 
 use FusionInventory::Agent::Tools;
+use FusionInventory::Agent::Version;
 
 my %fields = (
     BIOS             => [ qw/SMODEL SMANUFACTURER SSN BDATE BVERSION
@@ -24,8 +25,8 @@ my %fields = (
                              WINPRODKEY WINCOMPANY WINLANG CHASSIS_TYPE
                              VMNAME VMHOSTSERIAL/ ],
     OPERATINGSYSTEM  => [ qw/KERNEL_NAME KERNEL_VERSION NAME VERSION FULL_NAME
-                             SERVICE_PACK INSTALL_DATE FQDN DNS_DOMAIN
-                             SSH_KEY ARCH BOOT_TIME/ ],
+                             SERVICE_PACK INSTALL_DATE FQDN DNS_DOMAIN HOSTID
+                             SSH_KEY ARCH BOOT_TIME TIMEZONE/ ],
     ACCESSLOG        => [ qw/USERID LOGDATE/ ],
 
     ANTIVIRUS        => [ qw/COMPANY ENABLED GUID NAME UPTODATE VERSION
@@ -54,7 +55,7 @@ my %fields = (
                              MEMORYCORRECTION MANUFACTURER/ ],
     MODEMS           => [ qw/DESCRIPTION NAME TYPE MODEL/ ],
     MONITORS         => [ qw/BASE64 CAPTION DESCRIPTION MANUFACTURER SERIAL
-                             UUENCODE NAME TYPE/ ],
+                             UUENCODE NAME TYPE ALTSERIAL PORT/ ],
     NETWORKS         => [ qw/DESCRIPTION MANUFACTURER MODEL MANAGEMENT TYPE
                              VIRTUALDEV MACADDR WWN DRIVER FIRMWARE PCIID
                              PCISLOT PNPDEVICEID MTU SPEED STATUS SLAVES BASE
@@ -71,7 +72,7 @@ my %fields = (
                              CMD/ ],
     REGISTRY         => [ qw/NAME REGVALUE HIVE/ ],
     REMOTE_MGMT      => [ qw/ID TYPE/ ],
-    RUDDER           => [ qw/AGENT UUID HOSTNAME/ ],
+    RUDDER           => [ qw/AGENT UUID HOSTNAME SERVER_ROLES AGENT_CAPABILITIES/ ],
     SLOTS            => [ qw/DESCRIPTION DESIGNATION NAME STATUS/ ],
     SOFTWARES        => [ qw/COMMENTS FILESIZE FOLDER FROM HELPLINK INSTALLDATE
                             NAME NO_REMOVE RELEASE_TYPE PUBLISHER
@@ -87,9 +88,11 @@ my %fields = (
                             CLASS SUBCLASS NAME/ ],
     USERS            => [ qw/LOGIN DOMAIN/ ],
     VIRTUALMACHINES  => [ qw/MEMORY NAME UUID STATUS SUBSYSTEM VMTYPE VCPU
-                             MAC COMMENT OWNER SERIAL/ ],
+                             MAC COMMENT OWNER SERIAL IMAGE/ ],
     VOLUME_GROUPS    => [ qw/VG_NAME PV_COUNT LV_COUNT ATTR SIZE FREE VG_UUID
                              VG_EXTENT_SIZE/ ],
+    VERSIONPROVIDER  => [ qw/NAME VERSION COMMENTS PERL_EXE PERL_VERSION PERL_ARGS
+                             PROGRAM PERL_CONFIG PERL_INC PERL_MODULE/ ]
 );
 
 my %checks = (
@@ -126,7 +129,8 @@ sub new {
                 ARCHNAME => $Config{archname},
                 VMSYSTEM => "Physical" # Default value
             },
-            VERSIONCLIENT => $FusionInventory::Agent::AGENT_STRING
+            VERSIONCLIENT => $FusionInventory::Agent::AGENT_STRING ||
+                $FusionInventory::Agent::Version::PROVIDER."-Inventory_v".$FusionInventory::Agent::Version::VERSION
         }
     };
     bless $self, $class;
