@@ -16,14 +16,21 @@ sub doInventory {
     my $inventory = $params{inventory};
     my $logger    = $params{logger};
 
-    my $infos = getSystemProfilerInfos(type => 'SPApplicationsDataType', logger => $logger);
-
-    my $hostname =
-        $infos->{'Software'}->{'System Software Overview'}->{'Computer Name'};
+    my $hostname = _getHostname(
+        logger => $logger
+    );
 
     $inventory->setHardware({
         NAME => $hostname
     }) if $hostname;
 }
 
+sub _getHostname {
+    my (%params) = @_;
+
+    my $infos = getSystemProfilerInfos(type => 'SPSoftwareDataType', %params);
+
+    return $infos->{'Software'}->{'System Software Overview'}->{'Computer Name'};
+}
+
 1;
