@@ -29,7 +29,7 @@ sub doInventory {
     if ($params{scan_homedirs}) {
         push @transmitFiles, glob('/Users/*/Library/Preferences/com.panic.Transmit.plist');
     } else {
-        $logger->warning(
+        $logger->info(
             "'scan-homedirs' configuration parameters disabled, " .
             "ignoring transmit installations in user directories"
         );
