@@ -12,6 +12,13 @@ use File::stat;
 use File::Which;
 use Memoize;
 use UNIVERSAL::require;
+use List::Util qw(first);
+
+# Keep a copy of @ARGV, only for Provider inventory
+BEGIN {
+    our $ARGV = [ @ARGV ];
+}
+our $ARGV;
 
 our @EXPORT = qw(
     getDirectoryHandle
@@ -49,7 +56,7 @@ our @EXPORT = qw(
 
 my $nowhere = $OSNAME eq 'MSWin32' ? 'nul' : '/dev/null';
 
-# this trigger some errors on Perl 5.12/Win32:
+# this trigger some errors under win32:
 # Anonymous function called in forbidden scalar context
 if ($OSNAME ne 'MSWin32') {
     memoize('canRun');
@@ -347,7 +354,7 @@ sub getFirstMatch {
     }
     close $handle;
 
-    return wantarray ? @results : $results[0];
+    return wantarray ? @results : first { defined $_ } @results;
 }
 
 sub getAllLines {
